@@ -1,10 +1,37 @@
 carto <- function (Mat, MatH, level = 0, regmod = 1,   
-    coord = c(1, 2), asp = 1, cex = 1.3, col = "steelblue4", font = 2, clabel = 0.8,label.j=FALSE,resolution=200,nb.clusters=0)
+    	coord = c(1, 2), asp = 1, cex = 1.3, col = "steelblue4", font = 2, clabel = 0.8,label.j=FALSE,resolution=200,nb.clusters=0,
+		  graph.tree=TRUE,graph.corr=TRUE,graph.carto=TRUE,main=NULL,col.min=7.5,col.max=0)
 {
+#col : 0=red 
+#	1=orange
+#	2=red
+#	3=green
+#	4=green
+#	5=grenn/blue
+#	6=ligth blue
+#	7=blue
+#	8=dark blue
+#	9=purple
+#	10=pink
+#	11=pink
+# 	12=red
 
-dev.new()
-    op <- par(no.readonly = TRUE)
-    on.exit(par(op))
+cm.colors2=function (n, alpha = 1) {
+    	if ((n <- as.integer(n[1L])) > 0) {
+        	even.n <- n%%2 == 0
+        	k <- n%/%2
+        	l1 <- k + 1 - even.n
+        	l2 <- n - k + even.n
+        	c(if (l1 > 0) hsv(h = col.min/12, s = seq.int(0.8, ifelse(even.n, 
+            	0.5/k, 0), length.out = l1), v = 1, alpha = alpha), 
+            if (l2 > 1) hsv(h = col.max/12, s = seq.int(0, 0.8, length.out = l2)[-1L], 
+                v = 1, alpha = alpha))
+    	}
+    	else character(0L)
+}
+
+#    op <- par(no.readonly = TRUE)
+#    on.exit(par(op))
     predire <- function(n1, n2, coeff) {
         coeff[1] + coeff[2] * n1 + coeff[3] * n2 + coeff[4] *
             n1 * n1 + coeff[5] * n2 * n2 + coeff[6] * n1 * n2
@@ -12,13 +39,13 @@ dev.new()
     if (!is.data.frame(MatH)) stop("Non convenient selection for MatH")
     matrice <- cbind(row.names(MatH), Mat[rownames(MatH),],MatH)
     classif <- agnes(dist(t(MatH)),method="ward")
+if(graph.tree){
+    dev.new()
     plot(classif,main="Cluster Dendrogram",xlab="Panelists",which.plots=2)
-dev.new()
+}
     if (nb.clusters==0){
        classif2 <- as.hclust(classif)
        nb.clusters = which.max(rev(diff(classif2$height))) + 1
-#      classif=hopach(t(MatH),d="euclid",K=10,mss="mean")
-#      nb.clusters=classif$clustering$k
     }
     aux=kmeans(t(MatH),centers=nb.clusters)$cluster
     mat <- matrix(0,nb.clusters,nrow(MatH))
@@ -29,6 +56,8 @@ dev.new()
     } 
     ab=cor(t(mat),matrice[,2:3],use="pairwise.complete.obs")
     aa=cor(matrice[,4:ncol(matrice)],matrice[,2:3],use="pairwise.complete.obs")
+if(graph.corr){
+    dev.new()
     plot(0,0,xlab=paste("Dim",coord[1]),ylab=paste("Dim",coord[2]),xlim=c(-1,1),ylim=c(-1,1),col="white",asp=1,main="Correlation circle")
     x.cercle <- seq(-1, 1, by = 0.01)
     y.cercle <- sqrt(1 - x.cercle^2)
@@ -50,8 +79,8 @@ dev.new()
       else pos <- 2
       text(ab[v, 1], y = ab[v, 2], labels = rownames(ab)[v], pos = pos, offset=0.2, col="blue")
     }
+}
 
-dev.new()
     matrice[, 4:ncol(matrice)] <- scale(matrice[, 4:ncol(matrice)], center =TRUE, scale =FALSE)[, ]
     nbconso <- ncol(matrice) - 3
     x1 <- matrice[, 2]
@@ -97,10 +126,15 @@ dev.new()
         ordon <- c(ordon, f2[as.integer(1 + (rev(order(predites))[1] -
             0.5)/length(f1))])
     }
+    nb.depasse <- depasse
     depasse <- round(depasse/nbconso * 100)
     dimnames(depasse) <- list(as.character(f1), as.character(f2))
-    image(f1, f2, depasse, col = terrain.colors(200), xlab=paste("Dim",coord[1]), ylab=paste("Dim",coord[2]), main = "Preference mapping", font.main = font,
-        col.main = col, cex.main = cex, asp = asp)
+if(graph.carto){
+    dev.new()
+    col = cm.colors2(100)
+    if (is.null(main)) main = "Preference mapping"
+    image(f1, f2, depasse, col = col, xlab=paste("Dim",coord[1]), ylab=paste("Dim",coord[2]), main = main, font.main = font,
+        , cex.main = cex, asp = asp)
     contour(f1, f2, depasse, nlevels = 9, levels = c(20, 30,
         40, 50, 60, 70, 80, 90, 95), add =TRUE, labex = 0)
     for (i in 1:nrow(matrice)) {
@@ -108,11 +142,18 @@ dev.new()
         text(matrice[i, 2], matrice[i, 3], matrice[i,1],pos = 4, offset = 0.2,)
     }
     points(abscis, ordon, pch = 20)
+}
     don <- cbind.data.frame(as.factor(aux),t(MatH))
     colnames(don) <- c("clusters",paste("Prod",rownames(MatH),sep="."))
     resdecat <- decat(don,formul="~clusters",firstvar=2,proba=0.05,graph=FALSE)
     res <- list()
     res$clusters <- aux
     res$prod.clusters <- resdecat$resT
+    res$nb.depasse <- nb.depasse
+    res$f1<-f1
+    res$f2<-f2
+    res$abscis<-abscis
+    res$ordon<- ordon
+    res$matrice<- matrice
     return(res)
 }
